const mongoose = require('mongoose');

const Campaign = mongoose.model('Campaign');
const Subscriber = mongoose.model('Subscriber');
const Message = mongoose.model('Message');
const Merchant = mongoose.model('Merchant');
const  Wallet= mongoose.model("Wallet");
const { sendCampaignMessage } = require('../helpers/message.helper');
const { processCharge } = require('../helpers/stripe.helper');

const {
    MERCHANT_ACTIVE_STATUS,
    SUBSCRIBER_SUBSCIRBED_STATUS,
    CAMPAIGN_SCHEDULED_STATUS,
    CAMPAIGN_DELIVERED_STATUS
} = require('../helpers/status.helper');

const { TWILIO_API_KEY, TWILIO_AUTH_TOKEN } = process.env;
const twilio = require('twilio')(TWILIO_API_KEY, TWILIO_AUTH_TOKEN);

const MessagingResponse = require('twilio').twiml.MessagingResponse;

const processScheduledCampaigns = async (req, res) => {
    var conditoin ;
    const campaignsToProcess = await Campaign.find({
        status: CAMPAIGN_SCHEDULED_STATUS,
        date: { $lte: Date.now() }
    });  
    campaignsToProcess.forEach(async campaign => {
        const merchant = await Merchant.findOne({
            status: MERCHANT_ACTIVE_STATUS,
            _id: campaign.merchant
        });

        if (merchant) {
                if(campaign.price > 0){
                    conditoin = {
                        status: SUBSCRIBER_SUBSCIRBED_STATUS,
                        type:'iframe',
                        merchant: merchant._id,
                        isDeleted:0
                    }
                }
                if(campaign.price === 0 || campaign.price <= 0){
                    conditoin = {
                        merchant: merchant._id,
                        isDeleted:0
                    }
                }
            // const subscribersToMessage = await Subscriber.find({
            //     status: SUBSCRIBER_SUBSCIRBED_STATUS,
            //     merchant: merchant._id,
            //     isDeleted:0
            // });
            const subscribersToMessage = await Subscriber.find(conditoin);
            subscribersToMessage.forEach(async subscriber => {
                await sendCampaignMessage(subscriber, campaign, merchant);
            });
            
            // deduct amount from wallet 
            // const TotalApporxCharge = (0.0079+0.0200)*subscribersToMessage.length
            const TotalApporxCharge = (0.0200)*subscribersToMessage.length
            const wallet = await Wallet.findOne({merchant:campaign.merchant,amount: { $gt: 0},}).sort({ createdAt: -1 });
            if(wallet){
                wallet.amount = wallet.amount - TotalApporxCharge
                wallet.message_send += parseInt(subscribersToMessage.length);
                wallet.save();
            }else{
                console.log("trial runing");
            }
            
        }

        campaign.status = CAMPAIGN_DELIVERED_STATUS;
        await campaign.save();

    });


    return res.sendStatus(200);
};

const handleIncomingMessage = async (req, res) => {
    const twiml = new MessagingResponse();
    console.log("req.body =>",req.body)
    let preparedResponse;
    if (req.body.Body.toUpperCase() === 'stop' ) {
       const subscriber = await Subscriber.findOne({ phoneNumber: req.body.From ,isDeleted:0});
        if(subscriber){
                await Subscriber.deleteOne({ _id: subscriber._id })
                preparedResponse = `${subscriber?.firstName} You are Unsubscribed sucssfully ! Thanks `
                twiml.message(preparedResponse);
                res.writeHead(200, { 'Content-Type': 'text/xml' });
                res.end(twiml.toString());
                return
            }else{
            res.sendStatus(200);
            return 
         }
          
    }

    if(req.body.Body.toUpperCase() === 'HELP'){
        res.sendStatus(200);
        return
    }
    
    const lastMessage = await Message.findOne({
        from:req.params.from,
        to:  req.body.From,
        type: 'campaign'
    }, {}, { sort: { createdAt: -1 } });
    
    const lastMessageFromTwilio = await twilio.messages.list(
        {
        from:req.params.from,
        to: req.body.From,
        limit:1
    }
    )

    console.log("lastMessage in DB =>",lastMessage)
    console.log("lastMessageFromTwilio =>",lastMessageFromTwilio)



  //get all incoming messages
  const lastMessageFromSubscriber = await twilio.messages.list(
    {
    from:req.body.From,
    to:req.params.from,
    limit:1
}
)
    console.log("last message which is reply by the subscriber =>",lastMessageFromSubscriber)

    const subscriber = await Subscriber.findOne({ phoneNumber: req.body.From ,merchant:lastMessage.merchant,isDeleted:0});
    if (!subscriber) return res.sendStatus(200);

    console.log("subscriber =>",subscriber)

 

   const campaign = await Campaign.findById(lastMessage.campaign);
   console.log("campaign => ",campaign)

    const unitsBought = req.body.Body * 1;
    const shouldSendPurchaseConfirmationMessage = lastMessage.type === 'campaign'
        && typeof (unitsBought) === 'number' && lastMessage.twilio.id !== lastMessageFromTwilio[0].sid  && lastMessageFromSubscriber[0].body === req.body.Body ;
     
    console.log(unitsBought < 10 ," ==> ",shouldSendPurchaseConfirmationMessage)
     
    if(unitsBought >= 10){
            preparedResponse = `${subscriber.firstName} ! You cannot order that many units`
        }else if(unitsBought < 10 && !shouldSendPurchaseConfirmationMessage){

           preparedResponse=  `We want to make sure your order is correct! To confirm how many you'd like to order, please respond again with the number of items you would like.`
      
        }else if (unitsBought < 10 && shouldSendPurchaseConfirmationMessage) {   
                try {
                        const merchant = await Merchant.findById(subscriber.merchant);
                        await processCharge(subscriber, campaign, merchant, unitsBought);
                       
                        
                        preparedResponse = `Awesome, ${subscriber.firstName}!\n\nYou have just ordered ${unitsBought} items for a total of $${(campaign.price * parseInt(unitsBought)).toFixed(2)}.\n\nWe will ship this to you at ${subscriber.addressOne}${subscriber.addressTwo ? ` ${subscriber.addressTwo}` : ' '}\n${subscriber.city} ${subscriber.state} ${subscriber.zipCode}.\n\nThank you so much for your business!`;
                    } catch (e) {
                        console.log(e);
                        preparedResponse = `Bummer! We couldn't process your credit card.`;
                    }
                    
                    
                } else {
                    preparedResponse = 'Your last reply and current reply unite mismatched.';
                }

   console.log("prepared Response =>",preparedResponse)
 
    twiml.message(preparedResponse);

    res.writeHead(200, { 'Content-Type': 'text/xml' });
    res.end(twiml.toString());
};

const handleMessageStatusChange = async (req, res) => {
    console.log(req.body);
};

module.exports = {
    processScheduledCampaigns,
    handleIncomingMessage,
    handleMessageStatusChange
};