const mongoose = require('mongoose');
const { ApiError, Client, Environment } = require('square');
const Merchant = mongoose.model('Merchant');
require('dotenv').config();

const { SQ_SANDBOX_APP_ID, SQ_SANDBOX_APP_SECRET } = process.env;

const { generateToken } = require('../helpers/jwt.helper');

const squareClient = new Client({
    environment: Environment.Sandbox
});

const verify = async (req, res) => { };

const signup = async (req, res) => {
    
};

const install = async (req, res) => {
    const code = req.query.code;

    try {
        let { result } = await squareClient.oAuthApi.obtainToken({
            code,
            clientId: SQ_SANDBOX_APP_ID,
            clientSecret: SQ_SANDBOX_APP_SECRET,
            grantType: 'authorization_code'
        });

        const { accessToken, refreshToken, expiresAt, merchantId } = result;

        const doesMerchantExist = await Merchant.findOne({ merchant: merchantId });

        if (!doesMerchantExist) {
            const client = new Client({
                environment: Environment.Sandbox,
                accessToken
            });

            const merchantData = await client
                .merchantsApi
                .retrieveMerchant(merchantId);

            const {
                businessName,
                country,
                mainLocationId,
                status
            } = merchantData.result.merchant;

            const merchant = new Merchant({
                merchantId,
                name: businessName,
                country,
                mainLocationId,
                status,
                accessToken: {
                    token: accessToken,
                    expiresAt,
                },
                refreshToken
            });
            await merchant.save();

        } else {
            doesMerchantExist.accessToken = { token: accessToken, expiresAt };
            await doesMerchantExist.save();
        }

        const jwt = generateToken(merchantId);

        return res.status(200).json({ token: jwt });
    } catch (error) {
        console.log(error)
        if (error instanceof ApiError) {
            return res.sendStatus(error.statusCode);
        } else {
            return res.sendStatus(403);
        }
    }
}

module.exports = { install, verify };