const mongoose = require("mongoose");

const Longcode = mongoose.model("Longcode");


require("dotenv").config();

const { TWILIO_API_KEY, TWILIO_AUTH_TOKEN } = process.env;
const client = require('twilio')(TWILIO_API_KEY, TWILIO_AUTH_TOKEN);

const {
  LONGCODE_AVAILABLE_STATUS,
  LONGCODE_EXPIRED_STATUS,
} = require("./status.helper");

const twilio = require("twilio")(TWILIO_API_KEY, TWILIO_AUTH_TOKEN);

module.exports = {
  /**
   * Checks MongoDb for available Longcode resource
   * If has any, returns first available longcode
   * If not returns false
   *
   * @returns Boolean | String
   */
  checkForAvailableLongcodes: async () => {
    const longcodes = await Longcode.find({
      status: LONGCODE_AVAILABLE_STATUS,
    }).limit(1);

    if (longcodes.length) {
      return longcodes[0];
    } else {
      return false;
    }
  },

  /**
   * Pulls new longcode from Twilio API & creates new Longcode resource
   *
   * @returns Longcode resource
   */
  provisionNewLongcodeFromTwilio: async () => {
    const searchOptions = {
      limit: 1,
      smsEnabled: true,
    };

    const [twilioNumberResponse] = await twilio
      .availablePhoneNumbers("US")
      .local.list(searchOptions);

    const {
      phoneNumber,
      lata,
      locality,
      rateCenter,
      latitude,
      longitude,
      region,
      postalCode,
      isoCountry,
      capabilities,
    } = twilioNumberResponse;

    const smsUrl = `${process.env.TIWILO_API_URL}/message/incoming/${phoneNumber}/`;
    const smsFallbackUrl = `${process.env.TIWILO_API_URL}/message/incoming/fallback/${phoneNumber}/`;
    const statusCallback = `${process.env.TIWILO_API_URL}/message/status/${phoneNumber}/`;

    const newNumber = await twilio.incomingPhoneNumbers.create({
      phoneNumber,
      smsUrl,
      smsFallbackUrl,
      statusCallback,
    });

    const longcode = new Longcode({
      sid: newNumber.sid,
      phoneNumber,
      capabilities,
      lata,
      expiresAt: new Date(new Date().getTime() + 29 * 24 * 60 * 60 * 1000),
      country: isoCountry,
      locality,
      latitude,
      longitude,
      postalCode,
      rateCenter,
      region,
    });

    await longcode.save();
    return longcode.phoneNumber;
  },

  /**
   * Deletes a longcode from Twilio, cancelling billing
   * @param sid secret ID to delete Twilio resource
   *
   * @returns null
   */
  deleteLongcodeFromTwilio: async (sid) => {
    await twilio.incomingPhoneNumbers(sid).remove();
  },

  /**
   * Sets longcode to expired status
   * @param longcode Longcode resource
   *
   * @returns null
   */
  setLongcodeAsExpired: async (longcode) => {
    longcode.status = LONGCODE_EXPIRED_STATUS;

    await longcode.save();
  },

  getTwilioAllNumbers: async () => {
     const twilioNumber = await client.incomingPhoneNumbers.list()
    .then(incomingPhoneNumbers =>  {return incomingPhoneNumbers}
        );
    const randomNumber =   shuffleArray(twilioNumber)
    return randomNumber
  },

  
};
function shuffleArray(array) {
const randIndex = Math.floor(Math.random() * array.length);
const randNumber = array[randIndex]
return randNumber.phoneNumber
   
}