const bcrypt = require('bcrypt');
const mongoose = require('mongoose');

const Merchant = mongoose.model('Merchant');

/**
 * 
 * @param {string} password 
 * 
 * @returns hash - Hashed password
 */
const hashPassword = async password => {
    const salt = await bcrypt.genSalt();
    const hash = await bcrypt.hash(password, salt);

    return hash;
}

/**
 * 
 * @param {string} password 
 * 
 * @returns Boolean - Whether or not the password was valid
 */
const isValidPassword = async (submittedPassword, storedPassword) => {
    try {
        return await bcrypt.compare(submittedPassword, storedPassword);
    } catch (error) {
        throw new Error(error);
    }
};

/**
 * 
 * @param {string} str 
 */
const generateSlug = async str => {
    str = str.replace(/^\s+|\s+$/g, ''); // trim
    str = str.toLowerCase();

    // remove accents, swap ñ for n, etc
    var from = "àáäâèéëêìíïîòóöôùúüûñç·/_,:;";
    var to = "aaaaeeeeiiiioooouuuunc------";
    for (var i = 0, l = from.length; i < l; i++) {
        str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
    }

    str = str.replace(/[^a-z0-9 -]/g, '') // remove invalid chars
        .replace(/\s+/g, '-') // collapse whitespace and replace by -
        .replace(/-+/g, '-'); // collapse dashes

    const merchant = await Merchant.findOne({ subdomain: str });

    return merchant ? str + 1 : str;
}

module.exports = { hashPassword, isValidPassword, generateSlug };
