const mongoose = require('mongoose');

require('dotenv').config();

const Stripe = require('stripe');
const stripe = Stripe(process.env.STRIPE_SECRET_KEY);

const Order = mongoose.model('Order');

const { ORDER_IN_FULFILLMENT_STATUS } = require('./status.helper');

const processCharge = async (subscriber, campaign, merchant, unitsBought) => {
    try {
        const amount = parseInt(campaign.price * unitsBought * 100);
        console.log("# payment process start for amount # ",amount);
        const application_fee_amount = parseInt(merchant.commission * amount);
        const paymentIntent = await stripe.paymentIntents.create({
            amount,
            application_fee_amount,
            currency: 'usd',
            customer: subscriber.stripe.customer.id,
            payment_method: subscriber.stripe.customer.paymentMethod,
            off_session: true,
            confirm: true,
        }, {
            stripeAccount: merchant.stripe.account.id
        });
        console.log("# payment process end #");
        subscriber.amount = (subscriber.amount + (campaign.price * unitsBought)).toFixed(2);
        subscriber.orders += 1;

        campaign.performance.sold += unitsBought;
        campaign.performance.revenue = (campaign.performance.revenue +
            (campaign.price * unitsBought)).toFixed(2);

        const orders = await Order.find({ merchant: merchant.id });
        const order = new Order({
            number: `100${orders.length}`,
            date: Date.now(),
            total: (campaign.price * unitsBought).toFixed(2),
            quantity: unitsBought,
            status: ORDER_IN_FULFILLMENT_STATUS,
            subscriber: subscriber._id,
            subscriberInfo: {
                firstName: subscriber.firstName,
                lastName: subscriber.lastName,
            },
            merchant: merchant._id,
            campaign: campaign._id,
            stripe: {
                paymentIntent: {
                    id: paymentIntent.id
                }
            }
        });
        
        console.log("***** Order Created *****");
        await subscriber.save();
        await campaign.save();
        await order.save();

    } catch (e) {
        console.log(e);
    }
};

module.exports = { processCharge };