const Stripe = require('stripe');
const mongoose = require('mongoose');
const Order = mongoose.model('Order');
const Merchant = mongoose.model('Merchant');
const { decodeToken } = require('../helpers/jwt.helper');
const stripe = Stripe(process.env.STRIPE_SECRET_KEY);

const config = async (req, res) => {
  const merchant = await Merchant.findById(decodeToken(req.get("X-JWT-Token")).data.merchantId);
  const tomorrow = new Date(merchant.trial.endsAt)
  tomorrow.setDate(tomorrow.getDate() + 1)
  const order = await Order.find({
    merchant: decodeToken(req.get("X-JWT-Token")).data.merchantId,
    createdAt: {
      $gte: merchant.trial.startsAt,
      $lte: tomorrow
    }
  })
    .sort({ createdAt: -1 });
  var sumTotal = 0;
  if (order.length > 0) {
    for (var i = 0; i < order.length; i++) {
      sumTotal = order[i]['total'];
    }
  }
  const prices = await stripe.prices.list({
    lookup_keys: ['taxtanofferSubscription'],
    //  lookup_keys: ['textanofferSubscriptions'],
    expand: ['data.product']
  });
  res.status(200).send({
    publishableKey: process.env.STRIPE_PUBLISHABLE_KEY,
    prices: prices.data,
    sumTotal: parseInt((1 / 100) * (sumTotal * 100))
  });
}

const createSubscription = async (req, res) => {

  const customerId = req.body.customerId;
  const priceId = req.body.priceId;
  const sumtotal = req.body.sumTotal;
  const cardToken =req.body.cardToken
  var amount = parseInt(sumtotal)*0.1
  if(amount < 0.50){
    amount = 50
  }
  try {
   const subscription = await stripe.subscriptions.create({
      customer: customerId,
      items: [{
        price: priceId,
      }],
      payment_behavior: 'default_incomplete',
      expand: ['latest_invoice.payment_intent'],
    });

    const card = await stripe.customers.createSource(customerId,
      {source: cardToken}
    );
   // res.send({
    //   subscriptionId: subscription.id,
    //   clientSecret: subscription.latest_invoice.payment_intent.client_secret,
    // });
    return {
      subscriptionId: subscription.id,
      clientSecret: subscription.latest_invoice.payment_intent.client_secret,
     }
  } catch (error) {
    return res.status(400).send({ error: { message: error.message } });
  }
}

const invoicePerview = async (req, res) => {
  const customerId = req.cookies['customer'];
  const priceId = process.env[req.query.newPriceLookupKey.toUpperCase()];

  const subscription = await stripe.subscriptions.retrieve(
    req.query.subscriptionId
  );

  const invoice = await stripe.invoices.retrieveUpcoming({
    customer: customerId,
    subscription: req.query.subscriptionId,
    subscription_items: [{
      id: subscription.items.data[0].id,
      price: priceId,
    }],
  });

  res.send({ invoice });
}

const cancelSubscription = async (req, res) => {
  // Cancel the subscription
  try {
    const deletedSubscription = await stripe.subscriptions.del(
      req.body.subscriptionId
    );

    res.send({ subscription: deletedSubscription });
  } catch (error) {
    return res.status(400).send({ error: { message: error.message } });
  }
}

const updateSubscription = async (req, res) => {
  try {
    const subscription = await stripe.subscriptions.retrieve(
      req.body.subscriptionId
    );
    const updatedSubscription = await stripe.subscriptions.update(
      req.body.subscriptionId, {
      items: [{
        id: subscription.items.data[0].id,
        price: process.env[req.body.newPriceLookupKey.toUpperCase()],
      }],
    }
    );

    res.send({ subscription: updatedSubscription });
  } catch (error) {
    return res.status(400).send({ error: { message: error.message } });
  }
}

const subscriptions = async (req, res) => {
  // Simulate authenticated user. In practice this will be the
  // Stripe Customer ID related to the authenticated user.
  const customerId = req.cookies['customer'];

  const subscriptions = await stripe.subscriptions.list({
    customer: customerId,
    status: 'all',
    expand: ['data.default_payment_method'],
  });

  res.json({ subscriptions });
}


module.exports = { config, createSubscription }