const mongoose = require('mongoose');

const MerchantSchema = mongoose.Schema({
    name: String,
    owner: {
        firstName: String,
        lastName: String
    },
    email: {
        type: String,
        lowercase: true
    },
    password: String,
    addressOne: String,
    addressTwo: String,
    zipCode: String,
    city: String,
    state: String,
    country: String,
    phoneNumber: String,
    longcode: String,
    subdomain: String,
    status: { type: String, default: 'active' },
    stripe: {
        customer: {
            id: String,
            subscriptionId: String,
            clientSecret: String
        },
        account: {
            id: String,
            temporaryState: String,
            connected: { type: Boolean, default: false },
            emailRequired: { type: Boolean, default: false },
        }
    },
    square: {
        connected: { type: Boolean, default: false },
        merchantId: String,
        name: String,
        mainLocationId: String,
        status: String,
        accessToken: {
            token: String,
            expiresAt: Date,
        },
        refreshToken: String
    },
    headline: { type: String, default: "" },
    description: { type: String, default: "" },
    youtubeVideo: { type: String, default: "" },
    logo: { type: String, default: "" },
    commission: { type: Number, default: 0.1 },
    fontFamily: { type: String, default: '"Josefin Sans", sans-serif !important;' },
    fbPixel: String,
    ageWarning: { type: Boolean, default: false },
    plan: {
        type: String,
        enum: ['trial', 'paid'],
        default: 'trial'
    },
    trial: {
        startsAt: Date,
        endsAt: Date
    }
}, { timestamps: true });

module.exports = mongoose.model('Merchant', MerchantSchema);
