import { ApiResponse } from '../apiResponse';
import { RequestOptions } from '../http/requestBuilder';
import { ListMerchantsResponse } from '../models/listMerchantsResponse';
import { RetrieveMerchantResponse } from '../models/retrieveMerchantResponse';
import { BaseApi } from './baseApi';
export declare class MerchantsApi extends BaseApi {
    /**
     * Returns `Merchant` information for a given access token.
     *
     * If you don't know a `Merchant` ID, you can use this endpoint to retrieve the merchant ID for an
     * access token.
     * You can specify your personal access token to get your own merchant information or specify an OAuth
     * token
     * to get the information for the  merchant that granted you access.
     *
     * If you know the merchant ID, you can also use the [RetrieveMerchant](#endpoint-merchants-
     * retrievemerchant)
     * endpoint to get the merchant information.
     *
     * @param cursor The cursor generated by the previous response.
     * @return Response from the API call
     */
    listMerchants(cursor?: number, requestOptions?: RequestOptions): Promise<ApiResponse<ListMerchantsResponse>>;
    /**
     * Retrieve a `Merchant` object for the given `merchant_id`.
     *
     * @param merchantId  The ID of the merchant to retrieve. If the string "me" is supplied as the ID, then
     *                              retrieve the merchant that is currently accessible to this call.
     * @return Response from the API call
     */
    retrieveMerchant(merchantId: string, requestOptions?: RequestOptions): Promise<ApiResponse<RetrieveMerchantResponse>>;
}
