import { Schema } from '../schema';
import { Money } from './money';
/**
 * Defines the body parameters that can be included in
 * a request to the [CreateRefund](#endpoint-createrefund) endpoint.
 * Deprecated - recommend using [RefundPayment](#endpoint-refunds-refundpayment)
 */
export interface CreateRefundRequest {
    /**
     * A value you specify that uniquely identifies this
     * refund among refunds you've created for the tender.
     * If you're unsure whether a particular refund succeeded,
     * you can reattempt it with the same idempotency key without
     * worrying about duplicating the refund.
     * See [Idempotency keys](#idempotencykeys) for more information.
     */
    idempotencyKey: string;
    /**
     * The ID of the tender to refund.
     * A [`Transaction`](#type-transaction) has one or more `tenders` (i.e., methods
     * of payment) associated with it, and you refund each tender separately with
     * the Connect API.
     */
    tenderId: string;
    /**
     * A description of the reason for the refund.
     * Default value: `Refund via API`
     */
    reason?: string;
    /**
     * Represents an amount of money. `Money` fields can be signed or unsigned.
     * Fields that do not explicitly define whether they are signed or unsigned are
     * considered unsigned and can only hold positive amounts. For signed fields, the
     * sign of the value indicates the purpose of the money transfer. See
     * [Working with Monetary Amounts](https://developer.squareup.com/docs/build-basics/working-with-monetary-amounts)
     * for more information.
     */
    amountMoney: Money;
}
export declare const createRefundRequestSchema: Schema<CreateRefundRequest>;
