import { Schema } from '../schema';
import { SourceApplication } from './sourceApplication';
/**
 * Represents the transfer of a quantity of product inventory at a
 * particular time from one location to another.
 */
export interface InventoryTransfer {
    /**
     * A unique ID generated by Square for the
     * `InventoryTransfer`.
     */
    id?: string;
    /**
     * An optional ID provided by the application to tie the
     * `InventoryTransfer` to an external system.
     */
    referenceId?: string;
    /** Indicates the state of a tracked item quantity in the lifecycle of goods. */
    state?: string;
    /**
     * The Square ID of the [Location](#type-location) where the related
     * quantity of items were tracked before the transfer.
     */
    fromLocationId?: string;
    /**
     * The Square ID of the [Location](#type-location) where the related
     * quantity of items were tracked after the transfer.
     */
    toLocationId?: string;
    /**
     * The Square generated ID of the
     * `CatalogObject` being tracked.
     */
    catalogObjectId?: string;
    /**
     * The `CatalogObjectType` of the
     * `CatalogObject` being tracked.Tracking is only
     * supported for the `ITEM_VARIATION` type.
     */
    catalogObjectType?: string;
    /**
     * The number of items affected by the transfer as a decimal string.
     * Can support up to 5 digits after the decimal point.
     */
    quantity?: string;
    /**
     * A client-generated timestamp in RFC 3339 format that indicates when
     * the transfer took place. For write actions, the `occurred_at` timestamp
     * cannot be older than 24 hours or in the future relative to the time of the
     * request.
     */
    occurredAt?: string;
    /**
     * A read-only timestamp in RFC 3339 format that indicates when Square
     * received the transfer request.
     */
    createdAt?: string;
    /** Provides information about the application used to generate a change. */
    source?: SourceApplication;
    /**
     * The Square ID of the [Employee](#type-employee) responsible for the
     * inventory transfer.
     */
    employeeId?: string;
}
export declare const inventoryTransferSchema: Schema<InventoryTransfer>;
