import { Schema } from '../schema';
import { OrderFulfillmentPickupDetails } from './orderFulfillmentPickupDetails';
import { OrderFulfillmentShipmentDetails } from './orderFulfillmentShipmentDetails';
/** Contains details on how to fulfill this order. */
export interface OrderFulfillment {
    /** Unique ID that identifies the fulfillment only within this order. */
    uid?: string;
    /** The type of fulfillment. */
    type?: string;
    /** The current state of this fulfillment. */
    state?: string;
    /**
     * Application-defined data attached to this fulfillment. Metadata fields are intended
     * to store descriptive references or associations with an entity in another system or store brief
     * information about the object. Square does not process this field; it only stores and returns it
     * in relevant API calls. Do not use metadata to store any sensitive information (personally
     * identifiable information, card details, etc.).
     * Keys written by applications must be 60 characters or less and must be in the character set
     * `[a-zA-Z0-9_-]`. Entries may also include metadata generated by Square. These keys are prefixed
     * with a namespace, separated from the key with a ':' character.
     * Values have a max length of 255 characters.
     * An application may have up to 10 entries per metadata field.
     * Entries written by applications are private and can only be read or modified by the same
     * application.
     * See [Metadata](https://developer.squareup.com/docs/build-basics/metadata) for more information.
     */
    metadata?: Record<string, string>;
    /** Contains details necessary to fulfill a pickup order. */
    pickupDetails?: OrderFulfillmentPickupDetails;
    /** Contains details necessary to fulfill a shipment order. */
    shipmentDetails?: OrderFulfillmentShipmentDetails;
}
export declare const orderFulfillmentSchema: Schema<OrderFulfillment>;
