const express = require('express');
const aws = require('aws-sdk');
const multer = require('multer');
const multerS3 = require('multer-s3');

const s3 = new aws.S3({
    accessKeyId: process.env.S3_ACCESS_KEY_ID,
    secretAccessKey: process.env.S3_SECRET_ACCESS_KEY
});

const upload = multer({
    storage: multerS3({
        s3: s3,
        bucket: 'textanoffer',
        metadata: function (req, file, cb) {
            cb(null, { fieldName: file.fieldname });
        },
        key: function (req, file, cb) {
            cb(null, `${Date.now().toString()}.jpeg`)
        }
    })
});

const router = express.Router();

const {
    list,
    view,
    create,
    verify,
    verifyCode,
    preview
} = require('../controllers/campaign.controller');

const { verifyToken } = require('../middleware/jwt');

router.get('/list/', verifyToken, list);
router.get('/:campaignId/', verifyToken, view);

router.post('/create/', verifyToken, upload.single('file'), create);

router.post('/verify/', verifyToken, verify);
router.post('/verify/code/:verificationCode', verifyToken, verifyCode);

router.post('/preview/', verifyToken, preview);

module.exports = router;