const mongoose = require('mongoose');
const throng = require('throng');
const Stripe = require('stripe');
const stripe = Stripe(process.env.STRIPE_SECRET_KEY);
require('dotenv').config({ path: '.env' });

const mongooseOptions = {
    useNewUrlParser: true,
    useUnifiedTopology: true
};

mongoose.connect(`${process.env.MONGODB_URI}`, mongooseOptions);

mongoose.Promise = require('bluebird');
mongoose.connection.on('error', (err) => {
    console.error(`🚫 Database Error 🚫  → ${err}`);
});

function start() {
    require('./models/Merchant');
    require('./models/Campaign');
    require('./models/Subscriber');
    require('./models/Message');
    require('./models/Verify');
    require('./models/Order');
    require('./models/Longcode');
    require('./models/Wallet');

    const app = require('./app');
    app.get('/config', async (req, res) => {
        const prices = await stripe.prices.list({
          lookup_keys: ['textanofferSubscriptions'],
          expand: ['data.product']
        });
      
        res.send({
          publishableKey: process.env.STRIPE_PUBLISHABLE_KEY,
          prices: prices.data,
        });
      });

    app.set('port', process.env.PORT || 7777);
    const server = app.listen(app.get('port'), () => {
        console.log(`Express running → PORT ${server.address().port}`);
        console.log(`process.env.STRIPE_PUBLISHABLE_KEY ${process.env.STRIPE_PUBLISHABLE_KEY}`);
        console.log(`process.env.STRIPE_SECRET_KEY ${process.env.STRIPE_SECRET_KEY}`);

    });
}

throng({
    workers: process.env.WEB_CONCURRENCY || 1,
}, start);